# pulp_ansible_client

PulpAnsibleClient - the Ruby gem for the Pulp 3 API

Fetch, Upload, Organize, and Distribute Software Packages

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v3
- Package version: 0.6.0
- Build package: org.openapitools.codegen.languages.RubyClientCodegen
For more information, please visit [https://pulpproject.org](https://pulpproject.org)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build pulp_ansible_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./pulp_ansible_client-0.6.0.gem
```

(for development, run `gem install --dev ./pulp_ansible_client-0.6.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'pulp_ansible_client', '~> 0.6.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'pulp_ansible_client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'pulp_ansible_client'

# Setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR_USERNAME'
  config.password = 'YOUR_PASSWORD'
end

api_instance = PulpAnsibleClient::AnsibleCollectionsApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | name
  namespace: 'namespace_example', # String | namespace
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List collections
  result = api_instance.list(opts)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling AnsibleCollectionsApi->list: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *http://pulp*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*PulpAnsibleClient::AnsibleCollectionsApi* | [**list**](docs/AnsibleCollectionsApi.md#list) | **GET** /pulp/api/v3/ansible/collections/ | List collections
*PulpAnsibleClient::AnsibleCollectionsApi* | [**upload_collection**](docs/AnsibleCollectionsApi.md#upload_collection) | **POST** /ansible/collections/ | Upload a collection
*PulpAnsibleClient::AnsibleCopyApi* | [**copy_content**](docs/AnsibleCopyApi.md#copy_content) | **POST** /pulp/api/v3/ansible/copy/ | Copy content
*PulpAnsibleClient::ApiCollectionsApi* | [**get**](docs/ApiCollectionsApi.md#get) | **GET** {ansible_collection_href}api/v2/collections/ | 
*PulpAnsibleClient::ApiCollectionsApi* | [**post**](docs/ApiCollectionsApi.md#post) | **POST** {ansible_collection_href}api/v2/collections/ | 
*PulpAnsibleClient::ApiRolesApi* | [**get**](docs/ApiRolesApi.md#get) | **GET** {ansible_role_href}api/v1/roles/ | 
*PulpAnsibleClient::CollectionImportApi* | [**read**](docs/CollectionImportApi.md#read) | **GET** {ansible_collection_import_href} | Inspect a collection import
*PulpAnsibleClient::ContentCollectionVersionsApi* | [**create**](docs/ContentCollectionVersionsApi.md#create) | **POST** /pulp/api/v3/content/ansible/collection_versions/ | Create a collection version
*PulpAnsibleClient::ContentCollectionVersionsApi* | [**list**](docs/ContentCollectionVersionsApi.md#list) | **GET** /pulp/api/v3/content/ansible/collection_versions/ | List collection versions
*PulpAnsibleClient::ContentCollectionVersionsApi* | [**read**](docs/ContentCollectionVersionsApi.md#read) | **GET** {ansible_collection_version_href} | Inspect a collection version
*PulpAnsibleClient::ContentRolesApi* | [**create**](docs/ContentRolesApi.md#create) | **POST** /pulp/api/v3/content/ansible/roles/ | Create a role
*PulpAnsibleClient::ContentRolesApi* | [**list**](docs/ContentRolesApi.md#list) | **GET** /pulp/api/v3/content/ansible/roles/ | List roles
*PulpAnsibleClient::ContentRolesApi* | [**read**](docs/ContentRolesApi.md#read) | **GET** {ansible_role_href} | Inspect a role
*PulpAnsibleClient::DistributionsAnsibleApi* | [**create**](docs/DistributionsAnsibleApi.md#create) | **POST** /pulp/api/v3/distributions/ansible/ansible/ | Create an ansible distribution
*PulpAnsibleClient::DistributionsAnsibleApi* | [**delete**](docs/DistributionsAnsibleApi.md#delete) | **DELETE** {ansible_ansible_distribution_href} | Delete an ansible distribution
*PulpAnsibleClient::DistributionsAnsibleApi* | [**list**](docs/DistributionsAnsibleApi.md#list) | **GET** /pulp/api/v3/distributions/ansible/ansible/ | List ansible distributions
*PulpAnsibleClient::DistributionsAnsibleApi* | [**partial_update**](docs/DistributionsAnsibleApi.md#partial_update) | **PATCH** {ansible_ansible_distribution_href} | Update an ansible distribution
*PulpAnsibleClient::DistributionsAnsibleApi* | [**read**](docs/DistributionsAnsibleApi.md#read) | **GET** {ansible_ansible_distribution_href} | Inspect an ansible distribution
*PulpAnsibleClient::DistributionsAnsibleApi* | [**update**](docs/DistributionsAnsibleApi.md#update) | **PUT** {ansible_ansible_distribution_href} | Update an ansible distribution
*PulpAnsibleClient::GalaxyDetailApi* | [**get**](docs/GalaxyDetailApi.md#get) | **GET** {ansible_collection_href} | 
*PulpAnsibleClient::PulpAnsibleApiApi* | [**get**](docs/PulpAnsibleApiApi.md#get) | **GET** /pulp_ansible/galaxy/{path}/api/ | 
*PulpAnsibleClient::PulpAnsibleGalaxyApiCollectionsApi* | [**list**](docs/PulpAnsibleGalaxyApiCollectionsApi.md#list) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collections/ | 
*PulpAnsibleClient::PulpAnsibleGalaxyApiCollectionsApi* | [**read**](docs/PulpAnsibleGalaxyApiCollectionsApi.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collections/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleGalaxyApiCollectionsApi* | [**update**](docs/PulpAnsibleGalaxyApiCollectionsApi.md#update) | **PATCH** /pulp_ansible/galaxy/{path}/api/v3/collections/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleGalaxyApiV2VersionsApi* | [**get**](docs/PulpAnsibleGalaxyApiV2VersionsApi.md#get) | **GET** /pulp_ansible/galaxy/{path}/api/v2/collections/{namespace}/{name}/versions/{version}/ | 
*PulpAnsibleClient::PulpAnsibleGalaxyApiV3CollectionsApi* | [**create**](docs/PulpAnsibleGalaxyApiV3CollectionsApi.md#create) | **POST** /pulp_ansible/galaxy/{path}/api/v3/artifacts/collections/ | Upload a collection
*PulpAnsibleClient::PulpAnsibleGalaxyApiV3CollectionsDocsBlobApi* | [**read**](docs/PulpAnsibleGalaxyApiV3CollectionsDocsBlobApi.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collections/{namespace}/{name}/versions/{version}/docs-blob/ | 
*PulpAnsibleClient::PulpAnsibleGalaxyApiV3VersionsApi* | [**list**](docs/PulpAnsibleGalaxyApiV3VersionsApi.md#list) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collections/{namespace}/{name}/versions/ | 
*PulpAnsibleClient::PulpAnsibleGalaxyApiV3VersionsApi* | [**read**](docs/PulpAnsibleGalaxyApiV3VersionsApi.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collections/{namespace}/{name}/versions/{version}/ | 
*PulpAnsibleClient::PulpAnsibleTagsApi* | [**list**](docs/PulpAnsibleTagsApi.md#list) | **GET** /pulp/api/v3/pulp_ansible/tags/ | List tags
*PulpAnsibleClient::RemotesCollectionApi* | [**create**](docs/RemotesCollectionApi.md#create) | **POST** /pulp/api/v3/remotes/ansible/collection/ | Create a collection remote
*PulpAnsibleClient::RemotesCollectionApi* | [**delete**](docs/RemotesCollectionApi.md#delete) | **DELETE** {ansible_collection_remote_href} | Delete a collection remote
*PulpAnsibleClient::RemotesCollectionApi* | [**list**](docs/RemotesCollectionApi.md#list) | **GET** /pulp/api/v3/remotes/ansible/collection/ | List collection remotes
*PulpAnsibleClient::RemotesCollectionApi* | [**partial_update**](docs/RemotesCollectionApi.md#partial_update) | **PATCH** {ansible_collection_remote_href} | Update a collection remote
*PulpAnsibleClient::RemotesCollectionApi* | [**read**](docs/RemotesCollectionApi.md#read) | **GET** {ansible_collection_remote_href} | Inspect a collection remote
*PulpAnsibleClient::RemotesCollectionApi* | [**update**](docs/RemotesCollectionApi.md#update) | **PUT** {ansible_collection_remote_href} | Update a collection remote
*PulpAnsibleClient::RemotesRoleApi* | [**create**](docs/RemotesRoleApi.md#create) | **POST** /pulp/api/v3/remotes/ansible/role/ | Create a role remote
*PulpAnsibleClient::RemotesRoleApi* | [**delete**](docs/RemotesRoleApi.md#delete) | **DELETE** {ansible_role_remote_href} | Delete a role remote
*PulpAnsibleClient::RemotesRoleApi* | [**list**](docs/RemotesRoleApi.md#list) | **GET** /pulp/api/v3/remotes/ansible/role/ | List role remotes
*PulpAnsibleClient::RemotesRoleApi* | [**partial_update**](docs/RemotesRoleApi.md#partial_update) | **PATCH** {ansible_role_remote_href} | Update a role remote
*PulpAnsibleClient::RemotesRoleApi* | [**read**](docs/RemotesRoleApi.md#read) | **GET** {ansible_role_remote_href} | Inspect a role remote
*PulpAnsibleClient::RemotesRoleApi* | [**update**](docs/RemotesRoleApi.md#update) | **PUT** {ansible_role_remote_href} | Update a role remote
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**create**](docs/RepositoriesAnsibleApi.md#create) | **POST** /pulp/api/v3/repositories/ansible/ansible/ | Create an ansible repository
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**delete**](docs/RepositoriesAnsibleApi.md#delete) | **DELETE** {ansible_ansible_repository_href} | Delete an ansible repository
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**list**](docs/RepositoriesAnsibleApi.md#list) | **GET** /pulp/api/v3/repositories/ansible/ansible/ | List ansible repositorys
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**modify**](docs/RepositoriesAnsibleApi.md#modify) | **POST** {ansible_ansible_repository_href}modify/ | Modify Repository Content
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**partial_update**](docs/RepositoriesAnsibleApi.md#partial_update) | **PATCH** {ansible_ansible_repository_href} | Update an ansible repository
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**read**](docs/RepositoriesAnsibleApi.md#read) | **GET** {ansible_ansible_repository_href} | Inspect an ansible repository
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**sync**](docs/RepositoriesAnsibleApi.md#sync) | **POST** {ansible_ansible_repository_href}sync/ | 
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**update**](docs/RepositoriesAnsibleApi.md#update) | **PUT** {ansible_ansible_repository_href} | Update an ansible repository
*PulpAnsibleClient::RepositoriesAnsibleVersionsApi* | [**delete**](docs/RepositoriesAnsibleVersionsApi.md#delete) | **DELETE** {ansible_ansible_repository_version_href} | Delete a repository version
*PulpAnsibleClient::RepositoriesAnsibleVersionsApi* | [**list**](docs/RepositoriesAnsibleVersionsApi.md#list) | **GET** {ansible_ansible_repository_href}versions/ | List repository versions
*PulpAnsibleClient::RepositoriesAnsibleVersionsApi* | [**read**](docs/RepositoriesAnsibleVersionsApi.md#read) | **GET** {ansible_ansible_repository_version_href} | Inspect a repository version
*PulpAnsibleClient::RepositoriesAnsibleVersionsApi* | [**repair**](docs/RepositoriesAnsibleVersionsApi.md#repair) | **POST** {ansible_ansible_repository_version_href}repair/ | 
*PulpAnsibleClient::VersionsApi* | [**get**](docs/VersionsApi.md#get) | **GET** {ansible_role_href}versions/ | 
*PulpAnsibleClient::VersionsApi* | [**get_0**](docs/VersionsApi.md#get_0) | **GET** {ansible_collection_version_href}versions/ | 


## Documentation for Models

 - [PulpAnsibleClient::AnsibleAnsibleDistribution](docs/AnsibleAnsibleDistribution.md)
 - [PulpAnsibleClient::AnsibleAnsibleDistributionResponse](docs/AnsibleAnsibleDistributionResponse.md)
 - [PulpAnsibleClient::AnsibleAnsibleRepository](docs/AnsibleAnsibleRepository.md)
 - [PulpAnsibleClient::AnsibleAnsibleRepositoryResponse](docs/AnsibleAnsibleRepositoryResponse.md)
 - [PulpAnsibleClient::AnsibleCollectionRemote](docs/AnsibleCollectionRemote.md)
 - [PulpAnsibleClient::AnsibleCollectionRemoteResponse](docs/AnsibleCollectionRemoteResponse.md)
 - [PulpAnsibleClient::AnsibleCollectionResponse](docs/AnsibleCollectionResponse.md)
 - [PulpAnsibleClient::AnsibleCollectionVersion](docs/AnsibleCollectionVersion.md)
 - [PulpAnsibleClient::AnsibleCollectionVersionResponse](docs/AnsibleCollectionVersionResponse.md)
 - [PulpAnsibleClient::AnsibleRole](docs/AnsibleRole.md)
 - [PulpAnsibleClient::AnsibleRoleRemote](docs/AnsibleRoleRemote.md)
 - [PulpAnsibleClient::AnsibleRoleRemoteResponse](docs/AnsibleRoleRemoteResponse.md)
 - [PulpAnsibleClient::AnsibleRoleResponse](docs/AnsibleRoleResponse.md)
 - [PulpAnsibleClient::AnsibleTagResponse](docs/AnsibleTagResponse.md)
 - [PulpAnsibleClient::AsyncOperationResponse](docs/AsyncOperationResponse.md)
 - [PulpAnsibleClient::CollectionImportDetailResponse](docs/CollectionImportDetailResponse.md)
 - [PulpAnsibleClient::CollectionMetadataResponse](docs/CollectionMetadataResponse.md)
 - [PulpAnsibleClient::CollectionNamespaceResponse](docs/CollectionNamespaceResponse.md)
 - [PulpAnsibleClient::CollectionOneShot](docs/CollectionOneShot.md)
 - [PulpAnsibleClient::CollectionRefResponse](docs/CollectionRefResponse.md)
 - [PulpAnsibleClient::CollectionResponse](docs/CollectionResponse.md)
 - [PulpAnsibleClient::CollectionVersionDocsResponse](docs/CollectionVersionDocsResponse.md)
 - [PulpAnsibleClient::CollectionVersionResponse](docs/CollectionVersionResponse.md)
 - [PulpAnsibleClient::ContentSummary](docs/ContentSummary.md)
 - [PulpAnsibleClient::ContentSummaryResponse](docs/ContentSummaryResponse.md)
 - [PulpAnsibleClient::Copy](docs/Copy.md)
 - [PulpAnsibleClient::GalaxyCollection](docs/GalaxyCollection.md)
 - [PulpAnsibleClient::GalaxyCollectionResponse](docs/GalaxyCollectionResponse.md)
 - [PulpAnsibleClient::GalaxyCollectionVersionResponse](docs/GalaxyCollectionVersionResponse.md)
 - [PulpAnsibleClient::GalaxyRoleResponse](docs/GalaxyRoleResponse.md)
 - [PulpAnsibleClient::GalaxyRoleVersionResponse](docs/GalaxyRoleVersionResponse.md)
 - [PulpAnsibleClient::PaginatedCollectionResponseList](docs/PaginatedCollectionResponseList.md)
 - [PulpAnsibleClient::PaginatedCollectionVersionResponseList](docs/PaginatedCollectionVersionResponseList.md)
 - [PulpAnsibleClient::PaginatedGalaxyCollectionResponseList](docs/PaginatedGalaxyCollectionResponseList.md)
 - [PulpAnsibleClient::PaginatedGalaxyCollectionVersionResponseList](docs/PaginatedGalaxyCollectionVersionResponseList.md)
 - [PulpAnsibleClient::PaginatedGalaxyRoleResponseList](docs/PaginatedGalaxyRoleResponseList.md)
 - [PulpAnsibleClient::PaginatedGalaxyRoleVersionResponseList](docs/PaginatedGalaxyRoleVersionResponseList.md)
 - [PulpAnsibleClient::PaginatedRepositoryVersionResponseList](docs/PaginatedRepositoryVersionResponseList.md)
 - [PulpAnsibleClient::PaginatedTagResponseList](docs/PaginatedTagResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleAnsibleDistributionResponseList](docs/PaginatedansibleAnsibleDistributionResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleAnsibleRepositoryResponseList](docs/PaginatedansibleAnsibleRepositoryResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleCollectionRemoteResponseList](docs/PaginatedansibleCollectionRemoteResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleCollectionResponseList](docs/PaginatedansibleCollectionResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleCollectionVersionResponseList](docs/PaginatedansibleCollectionVersionResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleRoleRemoteResponseList](docs/PaginatedansibleRoleRemoteResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleRoleResponseList](docs/PaginatedansibleRoleResponseList.md)
 - [PulpAnsibleClient::PatchedCollection](docs/PatchedCollection.md)
 - [PulpAnsibleClient::PatchedansibleAnsibleDistribution](docs/PatchedansibleAnsibleDistribution.md)
 - [PulpAnsibleClient::PatchedansibleAnsibleRepository](docs/PatchedansibleAnsibleRepository.md)
 - [PulpAnsibleClient::PatchedansibleCollectionRemote](docs/PatchedansibleCollectionRemote.md)
 - [PulpAnsibleClient::PatchedansibleRoleRemote](docs/PatchedansibleRoleRemote.md)
 - [PulpAnsibleClient::PolicyEnum](docs/PolicyEnum.md)
 - [PulpAnsibleClient::RepositoryAddRemoveContent](docs/RepositoryAddRemoveContent.md)
 - [PulpAnsibleClient::RepositorySyncURL](docs/RepositorySyncURL.md)
 - [PulpAnsibleClient::RepositoryVersion](docs/RepositoryVersion.md)
 - [PulpAnsibleClient::RepositoryVersionResponse](docs/RepositoryVersionResponse.md)
 - [PulpAnsibleClient::TagResponse](docs/TagResponse.md)


## Documentation for Authorization


### basicAuth

- **Type**: HTTP basic authentication

