# PulpAnsibleClient::DistributionsAnsibleApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](DistributionsAnsibleApi.md#create) | **POST** /pulp/api/v3/distributions/ansible/ansible/ | Create an ansible distribution
[**delete**](DistributionsAnsibleApi.md#delete) | **DELETE** {ansible_ansible_distribution_href} | Delete an ansible distribution
[**list**](DistributionsAnsibleApi.md#list) | **GET** /pulp/api/v3/distributions/ansible/ansible/ | List ansible distributions
[**partial_update**](DistributionsAnsibleApi.md#partial_update) | **PATCH** {ansible_ansible_distribution_href} | Update an ansible distribution
[**read**](DistributionsAnsibleApi.md#read) | **GET** {ansible_ansible_distribution_href} | Inspect an ansible distribution
[**update**](DistributionsAnsibleApi.md#update) | **PUT** {ansible_ansible_distribution_href} | Update an ansible distribution



## create

> AsyncOperationResponse create(ansible_ansible_distribution)

Create an ansible distribution

Trigger an asynchronous create task

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::DistributionsAnsibleApi.new
ansible_ansible_distribution = PulpAnsibleClient::AnsibleAnsibleDistribution.new # AnsibleAnsibleDistribution | 

begin
  #Create an ansible distribution
  result = api_instance.create(ansible_ansible_distribution)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling DistributionsAnsibleApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ansible_ansible_distribution** | [**AnsibleAnsibleDistribution**](AnsibleAnsibleDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> AsyncOperationResponse delete(ansible_ansible_distribution_href)

Delete an ansible distribution

Trigger an asynchronous delete task

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::DistributionsAnsibleApi.new
ansible_ansible_distribution_href = 'ansible_ansible_distribution_href_example' # String | 

begin
  #Delete an ansible distribution
  result = api_instance.delete(ansible_ansible_distribution_href)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling DistributionsAnsibleApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ansible_ansible_distribution_href** | **String**|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list

> PaginatedansibleAnsibleDistributionResponseList list(opts)

List ansible distributions

ViewSet for Ansible Distributions.

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::DistributionsAnsibleApi.new
opts = {
  base_path: 'base_path_example', # String | base_path
  base_path__contains: 'base_path__contains_example', # String | base_path__contains
  base_path__icontains: 'base_path__icontains_example', # String | base_path__icontains
  base_path__in: 'base_path__in_example', # String | base_path__in
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | name
  name__in: 'name__in_example', # String | name__in
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List ansible distributions
  result = api_instance.list(opts)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling DistributionsAnsibleApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **base_path** | **String**| base_path | [optional] 
 **base_path__contains** | **String**| base_path__contains | [optional] 
 **base_path__icontains** | **String**| base_path__icontains | [optional] 
 **base_path__in** | **String**| base_path__in | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**| name | [optional] 
 **name__in** | **String**| name__in | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedansibleAnsibleDistributionResponseList**](PaginatedansibleAnsibleDistributionResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> AsyncOperationResponse partial_update(ansible_ansible_distribution_href, patchedansible_ansible_distribution)

Update an ansible distribution

Trigger an asynchronous partial update task

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::DistributionsAnsibleApi.new
ansible_ansible_distribution_href = 'ansible_ansible_distribution_href_example' # String | 
patchedansible_ansible_distribution = PulpAnsibleClient::PatchedansibleAnsibleDistribution.new # PatchedansibleAnsibleDistribution | 

begin
  #Update an ansible distribution
  result = api_instance.partial_update(ansible_ansible_distribution_href, patchedansible_ansible_distribution)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling DistributionsAnsibleApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ansible_ansible_distribution_href** | **String**|  | 
 **patchedansible_ansible_distribution** | [**PatchedansibleAnsibleDistribution**](PatchedansibleAnsibleDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> AnsibleAnsibleDistributionResponse read(ansible_ansible_distribution_href, opts)

Inspect an ansible distribution

ViewSet for Ansible Distributions.

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::DistributionsAnsibleApi.new
ansible_ansible_distribution_href = 'ansible_ansible_distribution_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect an ansible distribution
  result = api_instance.read(ansible_ansible_distribution_href, opts)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling DistributionsAnsibleApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ansible_ansible_distribution_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**AnsibleAnsibleDistributionResponse**](AnsibleAnsibleDistributionResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update

> AsyncOperationResponse update(ansible_ansible_distribution_href, ansible_ansible_distribution)

Update an ansible distribution

Trigger an asynchronous update task

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::DistributionsAnsibleApi.new
ansible_ansible_distribution_href = 'ansible_ansible_distribution_href_example' # String | 
ansible_ansible_distribution = PulpAnsibleClient::AnsibleAnsibleDistribution.new # AnsibleAnsibleDistribution | 

begin
  #Update an ansible distribution
  result = api_instance.update(ansible_ansible_distribution_href, ansible_ansible_distribution)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling DistributionsAnsibleApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ansible_ansible_distribution_href** | **String**|  | 
 **ansible_ansible_distribution** | [**AnsibleAnsibleDistribution**](AnsibleAnsibleDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

